@@ -666,3 +666,20 @@ test!(
     {"a":2,"b":3}
     "#
 );
+
+test!(
+    empty_flatten,
+    r#"
+    flatten(0, 1)
+    "#,
+    r#"
+    []
+    [[], []]
+    "#,
+    r#"
+    []
+    []
+    [[],[]]
+    []
+    "#
+);
